@@ -548,7 +548,10 @@ func (regtester *RegTester) executeSingleCmdFile(
 		}
 
 		// Write the .should-fail file
-		if actualExitCode != 0 {
+		if actualExitCode == 0 {
+			// Remove it, if it exists.
+			os.Remove(expectFailFileName)
+		} else {
 			err = regtester.storeFile(expectFailFileName, "")
 			if err != nil {
 				fmt.Printf("%s: %v\n", expectedStderrFileName, err)
@@ -558,7 +561,6 @@ func (regtester *RegTester) executeSingleCmdFile(
 					fmt.Printf("wrote %s\n", expectedStdoutFileName)
 				}
 			}
-
 		}
 
 		for pe := postCompareExpectedActualPairs.Front(); pe != nil; pe = pe.Next() {
@@ -773,6 +775,7 @@ func (regtester *RegTester) loadFile(
 	contents := string(byteContents)
 	contents = strings.ReplaceAll(contents, "${CASEDIR}", caseDir)
 	contents = strings.ReplaceAll(contents, "${PATHSEP}", string(os.PathSeparator))
+	contents = strings.ReplaceAll(contents, "${MLR}", regtester.exeName)
 	return contents, nil
 }
 
