@@ -1,5 +1,5 @@
-#mlrs="mlr5 ~/tmp/miller/mlr ./mlr"
-mlrs="mlr5 ./mlr"
+mlrs="mlr5 ~/tmp/miller/mlr ./mlr"
+#mlrs="mlr5 ./mlr"
 
 #reps="1"
 reps="1 2 3"
